<?php
/**
 * german language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Christof <gagi@fin.de>
 * @author Anika Henke <anika@selfthinker.org>
 * @author Esther Brunner <esther@kaffeehaus.ch>
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Michael Klier <chi@chimeric.de>
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Diese Seite bearbeiten';
$lang['btn_source']            = 'Zeige Quelltext';
$lang['btn_show']              = 'Seite anzeigen';
$lang['btn_create']            = 'Seite anlegen';
$lang['btn_search']            = 'Suche';
$lang['btn_save']              = 'Speichern';
$lang['btn_preview']           = 'Vorschau';
$lang['btn_top']               = 'Nach oben';
$lang['btn_newer']             = '<< jüngere Änderungen';
$lang['btn_older']             = 'ältere Änderungen >>';
$lang['btn_revs']              = 'Ältere Versionen';
$lang['btn_recent']            = 'Letzte Änderungen';
$lang['btn_upload']            = 'Hochladen';
$lang['btn_cancel']            = 'Abbrechen';
$lang['btn_index']             = 'Übersicht';
$lang['btn_secedit']           = 'Bearbeiten';
$lang['btn_login']             = 'Anmelden';
$lang['btn_logout']            = 'Abmelden';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Updaten';
$lang['btn_delete']            = 'Löschen';
$lang['btn_back']              = 'Zurück';
$lang['btn_backlink']          = 'Links hierher';
$lang['btn_backtomedia']       = 'Zurück zur Dateiauswahl';
$lang['btn_subscribe']         = 'Änderungen abonnieren';
$lang['btn_unsubscribe']       = 'Änderungen abbestellen';
$lang['btn_subscribens']       = 'Namensraumänderungen abonnieren';
$lang['btn_unsubscribens']     = 'Namensraumänderungen abbestellen';
$lang['btn_profile']           = 'Benutzerprofil';
$lang['btn_reset']             = 'Zurücksetzen';
$lang['btn_resendpwd']         = 'Sende neues Passwort';
$lang['btn_draft']             = 'Entwurf bearbeiten';
$lang['btn_recover']           = 'Entwurf wieder herstellen';
$lang['btn_draftdel']          = 'Entwurf löschen';
$lang['loggedinas']            = 'Angemeldet als';
$lang['user']                  = 'Benutzername';
$lang['pass']                  = 'Passwort';
$lang['newpass']               = 'Neues Passwort';
$lang['oldpass']               = 'Bestätigen (Altes Passwort)';
$lang['passchk']               = 'und nochmal';
$lang['remember']              = 'Angemeldet bleiben';
$lang['fullname']              = 'Voller Name';
$lang['email']                 = 'E-Mail';
$lang['register']              = 'Registrieren';
$lang['profile']               = 'Benutzerprofil';
$lang['badlogin']              = 'Nutzername oder Passwort sind falsch.';
$lang['minoredit']             = 'kleine Änderung';
$lang['draftdate']             = 'Entwurf gespeichert am';
$lang['nosecedit']             = 'Diese Seite wurde in der Zwischenzeit geändert, Sektionsinfo ist veraltet, lade stattdessen volle Seite.';
$lang['regmissing']            = 'Alle Felder müssen ausgefüllt werden';
$lang['reguexists']            = 'Der Nutzername existiert leider schon.';
$lang['regsuccess']            = 'Der neue Nutzer wurde angelegt und das Passwort per Email versandt.';
$lang['regsuccess2']           = 'Der neue Nutzer wurde angelegt.';
$lang['regmailfail']           = 'Offenbar ist ein Fehler beim Versenden der Passwortmail aufgetreten. Bitte wenden Sie sich an den Wiki-Admin.';
$lang['regbadmail']            = 'Die angegebene Mail-Adresse scheint ungültig zu sein. Falls dies ein Fehler ist, wenden Sie sich bitte an den Wiki-Admin.';
$lang['regbadpass']            = 'Die beiden eingegeben Passwörter stimmen nicht überein. Bitte versuchen Sie es noch einmal.';
$lang['regpwmail']             = 'Ihr DokuWiki Passwort';
$lang['reghere']               = 'Sie haben noch keinen Zugang? Hier anmelden';
$lang['profna']                = 'Änderung des Benutzerprofils in diesem Wiki nicht möglich.';
$lang['profnochange']          = 'Keine Änderungen, nichts zu tun.';
$lang['profnoempty']           = 'Es muß ein Name und eine E-Mail Adresse angegeben werden.';
$lang['profchanged']           = 'Benuzerprofil erfolgreich geändert.';
$lang['pwdforget']             = 'Passwort vergessen? Fordere ein neues an';
$lang['resendna']              = 'Passwörter versenden ist in diesem Wiki nicht möglich.';
$lang['resendpwd']             = 'Neues Passwort schicken für';
$lang['resendpwdmissing']      = 'Es tut mir Leid, aber Sie müssen alle Felder ausfüllen.';
$lang['resendpwdnouser']       = 'Es tut mir Leid, aber der Benutzer existiert nicht in unserer Datenbank.';
$lang['resendpwdbadauth']      = 'Es tut mir Leid, aber dieser Authentifizierungscode ist ungültig. Stellen Sie sicher, dass Sie den kompletten Bestätigungslink verwendet haben.';
$lang['resendpwdconfirm']      = 'Ein Bestätigungslink wurde per E-Mail versandt.';
$lang['resendpwdsuccess']      = 'Ihr neues Passwort wurde per E-Mail versandt.';
$lang['license']               = 'Falls nicht anders bezeichnet ist der Inhalt dieses Wikis unter der folgenden Lizenz veröffentlicht:';
$lang['licenseok']             = 'Hinweis: Durch das Bearbeiten dieser Seite geben Sie Ihr Einverständnis, dass Ihr Inhalt unter der folgenden Lizenz veröffentlicht wird:';
$lang['txt_upload']            = 'Datei zum Hochladen auswählen';
$lang['txt_filename']          = 'Hochladen als (optional)';
$lang['txt_overwrt']           = 'Bestehende Datei überschreiben';
$lang['lockedby']              = 'Momentan gesperrt von';
$lang['lockexpire']            = 'Sperre läuft ab am';
$lang['willexpire']            = 'Die Sperre zur Bearbeitung dieser Seite läuft in einer Minute ab.\nUm Bearbeitungskonflikte zu vermeiden, sollten Sie sie durch einen Klick auf den Vorschau-Knopf verlängern.';
$lang['notsavedyet']           = 'Nicht gespeicherte Änderungen gehen verloren!\nWeitermachen?';
$lang['rssfailed']             = 'Es ist ein Fehler beim Laden des Feeds aufgetreten: ';
$lang['nothingfound']          = 'Nichts gefunden.';
$lang['mediaselect']           = 'Dateiauswahl';
$lang['fileupload']            = 'Datei hochladen';
$lang['uploadsucc']            = 'Datei wurde erfolgreich hochgeladen';
$lang['uploadfail']            = 'Hochladen fehlgeschlagen. Keine Berechtigung?';
$lang['uploadwrong']           = 'Hochladen verweigert. Diese Dateiendung ist nicht erlaubt.';
$lang['uploadexist']           = 'Datei existiert bereits. Keine Änderungen vorgenommen.';
$lang['uploadbadcontent']      = 'Die hochgeladenen Daten stimmen nicht mit der Dateiendung % überein.';
$lang['uploadspam']            = 'Hochladen verweigert: Treffer auf der Spamliste.';
$lang['uploadxss']             = 'Hochladen verweigert: Daten scheinen Schadcode zu enthalten.';
$lang['uploadsize']            = 'Die hochgeladene Datei war zu groß. (max. %s)';
$lang['deletesucc']            = 'Die Datei "%s" wurde gelöscht.';
$lang['deletefail']            = '"%s" konnte nicht gelöscht werden - prüfen Sie die Berechtigungen.';
$lang['mediainuse']            = 'Die Datei "%s" wurde nicht gelöscht - sie wird noch verwendet.';
$lang['namespaces']            = 'Namensräume';
$lang['mediafiles']            = 'Vorhandene Dateien in';
$lang['js']['keepopen']        = 'Fenster nach Auswahl nicht schließen';
$lang['js']['hidedetails']     = 'Details ausblenden';
$lang['js']['nosmblinks']      = 'Das Verlinken von Windows Freigaben funktioniert nur im Microsoft Internet Explorer.
Der Link kann jedoch durch Kopieren und Einfügen verwendet werden.';
$lang['js']['mu_btn']          = 'Mehrere Dateien gleichzeitig hochladen';
$lang['mediausage']            = 'Syntax zum Verwenden dieser Datei:';
$lang['mediaview']             = 'Originaldatei öffnen';
$lang['mediaroot']             = 'Wurzel';
$lang['mediaupload']           = 'Laden Sie hier eine Datei in den momentanen Namensraum hoch. Um Unterordner zu erstellen, stellen Sie diese dem Dateinamen im Feld "Hochladen als" durch Doppelpunkt getrennt voran.';
$lang['mediaextchange']        = 'Dateiendung vom .%s nach .%s geändert!';
$lang['reference']             = 'Verwendung von';
$lang['ref_inuse']             = 'Diese Datei kann nicht gelöscht werden, da sie noch von folgenden Seiten benutzt wird:';
$lang['ref_hidden']            = 'Einige Verweise sind auf Seiten, für die Sie keine Leseberechtigung haben.';
$lang['hits']                  = 'Treffer';
$lang['quickhits']             = 'Passende Seitennamen';
$lang['toc']                   = 'Inhaltsverzeichnis';
$lang['current']               = 'aktuell';
$lang['yours']                 = 'Ihre Version';
$lang['diff']                  = 'Zeige Unterschiede zu aktueller Version';
$lang['diff2']                 = 'Zeige Unterschiede der ausgewählten Versionen';
$lang['line']                  = 'Zeile';
$lang['breadcrumb']            = 'Zuletzt angesehen';
$lang['youarehere']            = 'Sie befinden sich hier';
$lang['lastmod']               = 'Zuletzt geändert';
$lang['by']                    = 'von';
$lang['deleted']               = 'gelöscht';
$lang['created']               = 'angelegt';
$lang['restored']              = 'alte Version wieder hergestellt';
$lang['external_edit']         = 'Externe Bearbeitung';
$lang['summary']               = 'Zusammenfassung';
$lang['noflash']               = 'Das <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> wird benötigt, um diesen Ihnalt anzuzeigen.';
$lang['mail_newpage']          = 'Neue Seite:';
$lang['mail_changed']          = 'Seite geaendert:';
$lang['mail_new_user']         = 'Neuer Benutzer:';
$lang['mail_upload']           = 'Datei hochgeladen:';
$lang['qb_alert']              = 'Bitte geben Sie den zu formatierenden Text ein.\nDieser wird am Ende des Dokuments eingefügt.';
$lang['qb_bold']               = 'Fetter Text';
$lang['qb_italic']             = 'Kursiver Text';
$lang['qb_underl']             = 'Unterstrichener Text';
$lang['qb_code']               = 'Code Text';
$lang['qb_strike']             = 'Durchgestrichener Text';
$lang['qb_h1']                 = 'Level 1 Überschrift';
$lang['qb_h2']                 = 'Level 2 Überschrift';
$lang['qb_h3']                 = 'Level 3 Überschrift';
$lang['qb_h4']                 = 'Level 4 Überschrift';
$lang['qb_h5']                 = 'Level 5 Überschrift';
$lang['qb_link']               = 'Interner Link';
$lang['qb_extlink']            = 'Externer Link';
$lang['qb_hr']                 = 'Horizontale Linie';
$lang['qb_ol']                 = 'Nummerierter Listenpunkt';
$lang['qb_ul']                 = 'Listenpunkt';
$lang['qb_media']              = 'Bilder und andere Dateien hinzufügen';
$lang['qb_sig']                = 'Unterschrift einfügen';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Sonderzeichen';
$lang['del_confirm']           = 'Eintrag wirklich löschen?';
$lang['admin_register']        = 'Neuen Benutzer anmelden';
$lang['metaedit']              = 'Metadaten bearbeiten';
$lang['metasaveerr']           = 'Die Metadaten konnten nicht gesichert werden';
$lang['metasaveok']            = 'Metadaten gesichert';
$lang['img_backto']            = 'Zurück zu';
$lang['img_title']             = 'Titel';
$lang['img_caption']           = 'Bildunterschrift';
$lang['img_date']              = 'Datum';
$lang['img_fname']             = 'Dateiname';
$lang['img_fsize']             = 'Grösse';
$lang['img_artist']            = 'FotografIn';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Kamera';
$lang['img_keywords']          = 'Schlagwörter';
$lang['subscribe_success']     = '%s hat nun Änderungen der Seite %s abonniert';
$lang['subscribe_error']       = '%s kann die Änderungen der Seite %s nicht abonnieren';
$lang['subscribe_noaddress']   = 'Weil Ihre E-Mail-Adresse fehlt, können Sie das Thema nicht abonnieren';
$lang['unsubscribe_success']   = 'Das Abonnement von %s für die Seite %s wurde aufgelöst';
$lang['unsubscribe_error']     = 'Das Abonnement von %s für die Seite %s konnte nicht aufgelöst werden';
$lang['authmodfailed']         = 'Benutzerüberprüfung nicht möglich. Bitte wenden Sie sich an den Systembetreuer.';
$lang['authtempfail']          = 'Benutzerüberprüfung momentan nicht möglich. Falls das Problem andauert wenden Sie sich an den Systembetreuer.';
$lang['i_chooselang']          = 'Wählen Sie Ihre Sprache';
$lang['i_installer']           = 'DokuWiki Installation';
$lang['i_wikiname']            = 'Wiki-Name';
$lang['i_enableacl']           = 'Zugangskontrolle (ACL) aktivieren (empfohlen)';
$lang['i_superuser']           = 'Administrator Benutzername';
$lang['i_problems']            = 'Das Installationsprogramm hat unten aufgeführte Probleme festgestellt, die zunächst behoben werden müssen bevor Sie mit der Installation fortfahren können.';
$lang['i_modified']            = 'Aus Sicherheitsgründen arbeitet dieses Script nur mit einer neuen, unmodifizierten DokuWiki Installation.  Sie sollten entweder alle Dateien noch einmal frisch installieren oder die <a href="http://dokuwiki.org/install">Dokuwiki-Installationsanleitung</a> konsultieren.';
$lang['i_funcna']              = 'Die PHP Funktion <code>%s</code> ist nicht verfügbar. Unter Umständen wurde sie von Ihrem Hoster deaktiviert?';
$lang['i_phpver']              = 'Ihre PHP-Version <code>%s</code> ist niedriger als die benötigte Version <code>%s</code>. Bitte aktualisieren Sie Ihre PHP Installation.';
$lang['i_permfail']            = '<code>%s</code> ist nicht durch DokuWiki beschreibbar. Sie müssen die Berechtigungen dieses Ordners ändern!';
$lang['i_confexists']          = '<code>%s</code> existiert bereits';
$lang['i_writeerr']            = '<code>%s</code> konnte nicht erzeugt werden. Sie sollten die Verzeichnis-/Datei-Rechte überprüfen und die Datei manuell anlegen.';
$lang['i_badhash']             = 'Unbekannte oder modifizierte dokuwiki.php (Hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - unerlaubter oder leerer Wert';
$lang['i_success']             = 'Die Konfiguration wurde erfolgreich abgeschlossen. Sie können jetzt die install.php löschen. Ihr
                        <a href="doku.php">neues DokuWiki</a> ist jetzt für Sie bereit.';
$lang['i_failure']             = 'Es sind Fehler beim Schreiben der Konfigurationsdateien aufgetreten. Sie müssen diese vermutlich von Hand beheben, bevor Sie Ihr <a href="doku.php">neues DokuWiki</a> nutzen können.';
$lang['i_policy']              = 'Anfangseinstellung für Zugangskontrolle (ACL)';
$lang['i_pol0']                = 'Offenes Wiki (lesen, schreiben, hochladen für alle)';
$lang['i_pol1']                = 'Öffentliches Wiki (lesen für alle, schreiben und hochladen für registrierte Nutzer)';
$lang['i_pol2']                = 'Geschlossenes Wiki (lesen, schreiben, hochladen nur für registrierte Nutzer)';
$lang['i_retry']               = 'Wiederholen';
$lang['mu_intro']              = 'In diesem Bereich können Sie mehrere Dateien gleichzeitig hochladen. Benutzen Sie die Schaltfläche "Durchsuchen" um sie der Warteschlange zuzufügen. Betätigen Sie die Schaltfläche "Hochladen" um die Übertragung zu starten.';
$lang['mu_gridname']           = 'Dateiname';
$lang['mu_gridsize']           = 'Größe';
$lang['mu_gridstat']           = 'Status';
$lang['mu_namespace']          = 'Namensraum';
$lang['mu_browse']             = 'Durchsuchen';
$lang['mu_toobig']             = 'zu groß';
$lang['mu_ready']              = 'bereit zum hochladen';
$lang['mu_done']               = 'fertig';
$lang['mu_fail']               = 'gescheitert';
$lang['mu_authfail']           = 'Sitzung abgelaufen';
$lang['mu_progress']           = '@PCT@% hochgeladen';
$lang['mu_filetypes']          = 'Erlaubte Dateitypen';
$lang['recent_global']         = 'Im Moment sehen Sie die Änderungen im Namensraum <b>%s</b>. Sie können auch <a href="%s">die Änderungen im gesamten Wiki sehen</a>.';
